Module algorithm

Module algorithm 

Functions

algorithm_name
Computes a proper display name for the give COSE algorithm.
instantiate_algorithm
Converts a COSE algorithm into an SSI algorithm instance.
preferred_algorithm
Returns the preferred signature algorithm for the give COSE key.