pub enum CoseError {
DecodeFailed(Error<EndOfFile>),
DuplicateMapKey,
EncodeFailed,
ExtraneousData,
OutOfRangeIntegerValue,
UnexpectedItem(&'static str, &'static str),
UnregisteredIanaValue,
UnregisteredIanaNonPrivateValue,
}Expand description
Error type for failures in encoding or decoding COSE types.
Variants
DecodeFailed(Error<EndOfFile>)
CBOR decoding failure.
DuplicateMapKey
Duplicate map key detected.
EncodeFailed
CBOR encoding failure.
ExtraneousData
CBOR input had extra data.
OutOfRangeIntegerValue
Integer value on the wire is outside the range of integers representable in this crate. See https://crates.io/crates/coset/#integer-ranges.
UnexpectedItem(&'static str, &'static str)
Unexpected CBOR item encountered (got, want).
UnregisteredIanaValue
Unrecognized value in IANA-controlled range (with no private range).
UnregisteredIanaNonPrivateValue
Unrecognized value in neither IANA-controlled range nor private range.