pub struct CoseKey {
pub kty: RegisteredLabel<KeyType>,
pub key_id: Vec<u8>,
pub alg: Option<RegisteredLabelWithPrivate<Algorithm>>,
pub key_ops: BTreeSet<RegisteredLabel<KeyOperation>>,
pub base_iv: Vec<u8>,
pub params: Vec<(Label, Value)>,
}Expand description
Structure representing a cryptographic key.
COSE_Key = {
1 => tstr / int, ; kty
? 2 => bstr, ; kid
? 3 => tstr / int, ; alg
? 4 => [+ (tstr / int) ], ; key_ops
? 5 => bstr, ; Base IV
* label => values
}Fields
kty: RegisteredLabel<KeyType>Key type identification.
key_id: Vec<u8>Key identification.
alg: Option<RegisteredLabelWithPrivate<Algorithm>>Key use restriction to this algorithm.
key_ops: BTreeSet<RegisteredLabel<KeyOperation>>Restrict set of possible operations.
base_iv: Vec<u8>Base IV to be xor-ed with partial IVs.
params: Vec<(Label, Value)>Any additional parameter (label,value) pairs. If duplicate labels are present, CBOR-encoding will fail.
Implementations
Sourceimpl CoseKey
impl CoseKey
Sourcepub fn canonicalize(&mut self, ordering: CborOrdering)
pub fn canonicalize(&mut self, ordering: CborOrdering)
Re-order the contents of the key so that the contents will be emitted in one of the standard CBOR sorted orders.