DecodedCoseSign1

Struct DecodedCoseSign1 

pub struct DecodedCoseSign1<T = ()> {
    pub signing_bytes: UnsignedCoseSign1<T>,
    pub signature: CoseSignatureBytes,
}
Decoded COSE_Sign1 object.

Fields

signing_bytes: UnsignedCoseSign1<T>

Signing bytes.

signature: CoseSignatureBytes

Signature.

Implementations

Source

impl<T> DecodedCoseSign1<T>

pub async fn verify<P>( &self, params: P, ) -> Result<Verification, ProofValidationError>

Verify.

Source

impl<T> DecodedCoseSign1<T>

pub fn map<U>(self, f: impl FnOnce(T, &[u8]) -> U) -> DecodedCoseSign1<U>

Maps the payload interpretation.

This function can be used to decode the raw payload bytes into a proper typed value the application can work with.

pub fn try_map<U, E>( self, f: impl FnOnce(T, &[u8]) -> Result<U, E>, ) -> Result<DecodedCoseSign1<U>, E>

Tries to map the payload interpretation.

This function can be used to decode the raw payload bytes into a proper typed value the application can work with.