ProtectedHeader

Struct ProtectedHeader 

pub struct ProtectedHeader {
    pub original_data: Option<Vec<u8>>,
    pub header: Header,
}
Structure representing a protected COSE header map.

Fields

original_data: Option<Vec<u8>>

If this structure was created by parsing serialized data, this field holds the entire contents of the original bstr data.

header: Header

Parsed header information.

Implementations

Source

impl ProtectedHeader

pub fn from_cbor_bstr(val: Value) -> Result<ProtectedHeader, CoseError>

Constructor from a Value that holds a bstr encoded header.

pub fn cbor_bstr(self) -> Result<Value, CoseError>

Convert this header to a bstr encoded map, as a Value, consuming the object along the way.

pub fn is_empty(&self) -> bool

Indicate whether the ProtectedHeader is empty.