pub enum Label {
Int(i64),
Text(String),
}Expand description
A COSE label may be either a signed integer value or a string.
Variants
Implementations
Sourceimpl Label
impl Label
Sourcepub fn cmp_canonical(&self, other: &Label) -> Ordering
pub fn cmp_canonical(&self, other: &Label) -> Ordering
Alternative ordering for Label, using the canonical ordering criteria from RFC 7049
section 3.9 (where the primary sorting criterion is the length of the encoded form), rather
than the ordering given by RFC 8949 section 4.2.1 (lexicographic ordering of encoded form).
Panics
Panics if either Label fails to serialize.