pub struct DecodedCoseSign1<T = ()> {
pub signing_bytes: UnsignedCoseSign1<T>,
pub signature: CoseSignatureBytes,
}Expand description
Decoded COSE_Sign1 object.
Fields
signing_bytes: UnsignedCoseSign1<T>Signing bytes.
signature: CoseSignatureBytesSignature.
Implementations
Sourceimpl<T> DecodedCoseSign1<T>
impl<T> DecodedCoseSign1<T>
Sourcepub async fn verify<P>(
&self,
params: P,
) -> Result<Verification, ProofValidationError>where
T: ValidateCoseHeader<P> + ValidateClaims<P, CoseSignatureBytes>,
P: ResolverProvider<Resolver: CoseKeyResolver>,
pub async fn verify<P>(
&self,
params: P,
) -> Result<Verification, ProofValidationError>where
T: ValidateCoseHeader<P> + ValidateClaims<P, CoseSignatureBytes>,
P: ResolverProvider<Resolver: CoseKeyResolver>,
Verify.
Sourceimpl<T> DecodedCoseSign1<T>
impl<T> DecodedCoseSign1<T>
Sourcepub fn map<U>(self, f: impl FnOnce(T, &[u8]) -> U) -> DecodedCoseSign1<U>
pub fn map<U>(self, f: impl FnOnce(T, &[u8]) -> U) -> DecodedCoseSign1<U>
Maps the payload interpretation.
This function can be used to decode the raw payload bytes into a proper typed value the application can work with.