pub struct PayloadBytes<T = ()> { /* private fields */ }Expand description
Payload and bytes.
Stores the payload value as interpreted by the application (type T) and
the original payload bytes.
The original payload bytes are always preserved since they can not always be deterministically (or cheaply) reconstructed from the typed payload value.
Implementations
Sourceimpl PayloadBytes
impl PayloadBytes
Sourcepub fn from_bytes(bytes: Vec<u8>) -> Self
pub fn from_bytes(bytes: Vec<u8>) -> Self
Creates a new PayloadBytes from the bytes.
The interpretation of the bytes will be unit ().
Sourceimpl<T: CosePayload> PayloadBytes<T>
impl<T: CosePayload> PayloadBytes<T>
Sourcepub fn new(value: T) -> Self
pub fn new(value: T) -> Self
Creates a new PayloadBytes from the payload, using
CosePayload::payload_bytes to reconstruct the payload bytes.
Sourceimpl<T> PayloadBytes<T>
impl<T> PayloadBytes<T>
Sourcepub fn map<U>(self, f: impl FnOnce(T, &[u8]) -> U) -> PayloadBytes<U>
pub fn map<U>(self, f: impl FnOnce(T, &[u8]) -> U) -> PayloadBytes<U>
Maps the payload interpretation.
This function can be used to decode the raw payload bytes into a proper typed value the application can work with.
Sourcepub fn try_map<U, E>(
self,
f: impl FnOnce(T, &[u8]) -> Result<U, E>,
) -> Result<PayloadBytes<U>, E>
pub fn try_map<U, E>( self, f: impl FnOnce(T, &[u8]) -> Result<U, E>, ) -> Result<PayloadBytes<U>, E>
Tries to map the payload interpretation.
This function can be used to decode the raw payload bytes into a proper typed value the application can work with.
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Forgets about the payload interpretation and returns the raw bytes.