pub struct ProtectedHeader {
pub original_data: Option<Vec<u8>>,
pub header: Header,
}Expand description
Structure representing a protected COSE header map.
Fields
original_data: Option<Vec<u8>>If this structure was created by parsing serialized data, this field
holds the entire contents of the original bstr data.
header: HeaderParsed header information.
Implementations
Sourceimpl ProtectedHeader
impl ProtectedHeader